# Generated by Django 3.2.4 on 2021-08-01 17:21

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('edc_registration', '0021_auto_20200513_0023'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='historicalregisteredsubject',
            name='identity_or_pk',
        ),
        migrations.RemoveField(
            model_name='registeredsubject',
            name='identity_or_pk',
        ),
    ]
